#!/usr/bin/env python3
"""Colors used across themes."""
# colors from https://blueprintjs.com/docs/#core/colors

# intended to approximate the standard ordering found in cat10 or similar. For
# my purposes, it's rare that you're using all of them and that you need maximum
# visual clarity. What's more common is using a couple colors or using them
# redundantly. If you want maximum discernability, use Glasbey from colorcet.

# An example of this tradeoff: blue and orange are the easiest pair to tell
# apart, which is why you see them in Rocket League or Splatoon or similar games
# with teams. But blue and green look much nicer as the only two colors in a
# plot, and they're still discernible with most forms of colorblindness. So blue
# and green are the first pair, and then orange is the third color.

LIGHT_COLORS = [
    "#215DB0",
    "#1C6E42",
    "#935610",
    "#B83211",
    "#7C327C",
    "#0F6894",
    "#634DBF",
    "#5A701A",
    "#C22762",
    "#866103",
]

DARK_COLORS = [
    "#4C90F0",
    "#32A467",
    "#EC9A3C",
    "#EB6847",
    "#BD6BBD",
    "#3FA6DA",
    "#9881F3",
    "#B6D94C",
    "#F5498B",
    "#F0B726",
]

# the neutrals are from https://elastic.github.io/eui/#/theming/colors
# the naming is from a light-scheme perspective

LIGHT_SHADES = [
    # empty shade: primary background
    "#FFFFFF",
    # lightest shade: secondary background
    "#F1F4FA",
    # light shade: borders and dividers
    "#D3DAE6",
    # medium shade: subdued text
    "#98A2B3",
    # dark shade: secondary foreground
    "#69707D",
    # darkest shade: primary foreground, text
    "#343741",
]

DARK_SHADES = [
    # empty shade: primary background
    "#1D1E24",
    # lightest shade: secondary background
    "#25262E",
    # light shade: borders and dividers
    "#343741",
    # medium shade: subdued text
    "#535966",
    # dark shade: secondary foreground
    "#98A2B3",
    # darkest shade: primary foreground, text
    "#D4DAE5",
]



#!/usr/bin/env python3
"""Matplotlib themes as dictionaries."""

from typing import List, Tuple
from .colors import LIGHT_COLORS, DARK_COLORS, LIGHT_SHADES, DARK_SHADES
import matplotlib as mpl
import matplotlib.pyplot as plt

# Colors are taken from BlueprintJS. Background-foreground colors are default in Elastic UI.

rho = {
    # text sizes
    "font.size": 12,
    "axes.labelsize": "large",
    "axes.titlesize": "x-large",
    "figure.titlesize": "xx-large",
    # text weights
    "axes.titleweight": 400,
    "figure.titleweight": 700,
    # if grid is turned on, have it go below plots
    "axes.axisbelow": "false",
    "grid.linestyle": "-",
    "grid.linewidth": 1.0,
    # turn off grid by default
    "axes.grid": "false",
    # turn off ticks on axes
    "xtick.major.size": 0,
    "xtick.minor.size": 0,
    "ytick.major.size": 0,
    "ytick.minor.size": 0,
    # sans-serif by default
    "font.family": "sans-serif",
    # use Computer Modern for LaTeX
    "mathtext.fontset": "cm",
    # turn off right and top spines
    "axes.spines.right": "false",
    "axes.spines.top": "false",
    # set default figure size to a bit more than 6.4 x 4.8
    "figure.figsize": (8, 6),
}


rho_light = rho.copy()
rho_dark = rho.copy()

rho_light["axes.prop_cycle"] = mpl.cycler(
    # remove # from color beginning
    color=[x[1:] for x in LIGHT_COLORS]
)

rho_light["axes.prop_cycle"] = mpl.cycler(
    # remove # from color beginning
    color=[x[1:] for x in DARK_COLORS]
)


for rc, shades in [(rho_light, LIGHT_SHADES), (rho_dark, DARK_SHADES)]:
    empty, lightest, light, medium, dark, darkest = shades
    rc["figure.facecolor"] = lightest
    rc["savefig.facecolor"] = lightest
    rc["axes.facecolor"] = lightest

    rc["axes.edgecolor"] = light
    rc["figure.edgecolor"] = light
    rc["savefig.edgecolor"] = light
    rc["legend.edgecolor"] = light

    rc["xtick.color"] = medium
    rc["ytick.color"] = medium

    rc["xtick.labelcolor"] = dark
    rc["ytick.labelcolor"] = dark
    rc["legend.labelcolor"] = dark

    rc["text.color"] = darkest
    rc["axes.labelcolor"] = darkest
    rc["axes.titlecolor"] = darkest


def setup(is_dark: bool) -> Tuple[dict, List[str]]:
    """Sets up Matplotlib according to the given color scheme. Returns the theme and colors as a tuple."""
    theme = rho_dark if is_dark else rho_light
    return (theme, [x["color"] for x in theme["axes.prop_cycle"]])
